#include "testlib.h"

#pragma comment(linker, "/STACK:256000000")

using namespace std;

typedef long long int ll;

void skip_group()
{
	static const char rareChar = '%';
	static const string randomString = "KSDJFWLWERKsdfwEWR234dft34TEGR";
	static const string groupToken = "GROUP: ";
	static const char terminalToken = '#';
	
	string toParse = randomString + groupToken;
	string read;
	
	char c = inf.readChar();
	if (c != rareChar)
	{
		inf.unreadChar(c);
		return;
	}
	
	for (size_t i = 0; i < toParse.size(); i++)
	{
		if (!inf.eof()) read += inf.readChar();
	}

	ensuref(!inf.eof() && read == toParse, "Bad fake group format");

	string group;

	c = inf.readChar();
	while (c != terminalToken)
	{
		group += c;
		ensuref(!inf.eof(), "Bad fake group format");
		c = inf.readChar();
	}
	
	inf.readEoln();
}

int n;
string st;

bool read_ans(InStream& in)
{
	int ans_sz = in.readInt(-1, n, "ans_sz");
	
	if (ans_sz == -1)
	{
		in.seekEof();
		in.readEof();
		return false;
	}
	
	vector<bool> used(n, false);

	for (int i = 0; i < ans_sz; ++i)
	{
		int cur_sz = in.readInt(1, n, "l[" + vtos(i) + "]");
		if (cur_sz % 2 == 0) in.quitf(_wa, "Wrong zig-zag length %d", cur_sz);
		
		int last = 0;
		for (int j = 0; j < cur_sz; ++j)
		{
			int cur_elem = in.readInt(last + 1, n, "z[" + vtos(i) + "][" + vtos(j) + "]");
			last = cur_elem;
			--cur_elem;

			if (used[cur_elem]) in.quitf(_wa, "%d element used twice", cur_elem + 1);
			if (j % 2 != st[cur_elem] - '0') in.quitf(_wa, "Wrong zig-zag element: i = %d, j = %d", i, j);
			
			used[cur_elem] = true;
		}
	}
	
	for (int i = 0; i < n; ++i)
	{
		if (!used[i]) in.quitf(_wa, "%d element unused", i + 1);
	}

	in.seekEof();
	in.readEof();

	return true;
}

int main(int argc, char **argv)
{
	registerTestlibCmd(argc, argv);

	skip_group();

	st = inf.readToken();
	n = (int)st.size();
	
	bool jans = read_ans(ans);
	bool pans = read_ans(ouf);

	if (jans && pans)
	{
		quitf(_ok, "Participant and Jury found the correct answer");
	}
	else if (!jans && !pans)
	{
		quitf(_ok, "Participant and Jury didn't find the answer");
	}
	else if (jans && !pans)
	{
		quitf(_wa, "Participant didn't find the answer but Jury found");
	}
	else // (!jans && pans)
	{
		quitf(_fail, "Jury didn't find the answer but Participant found");
	}

	return 0;
}

